@@ -4,9 +4,10 @@ import logging
 import argparse
 import pandas as pd
 from pathlib import Path
+from logging.handlers import RotatingFileHandler
 from inspect import signature, Parameter
+from pyhard import integrator, log_file
 from pyhard.context import Configuration
-from pyhard.integrator import build_metadata, run_matilda
 from pyhard.visualization import Demo, App
 from pyhard.feature_selection import featfilt
 from pyhard.app import graphene
@@ -16,11 +17,18 @@ from pyhard.hpo import set_hyperopt_progressbar
 
 def main():
     logger = logging.getLogger(__name__)
-    _my_path = Path(__file__).parents[1]
+    _my_path = Path().absolute()
 
-    with Configuration(args.other) as conf:
-        # TODO: send this to Configuration().__enter__()
+    if args.other is None:
+        config_path = _my_path / 'config.yaml'
+    else:
+        config_path = args.other
+
+    with Configuration(config_path) as conf:
+        logger.info(f"Configuration file: '{str(config_path)}'")
         for name, path_str in conf.get(['rootdir', 'matildadir', 'datafile']).items():
+            if path_str is None:
+                continue
             path = Path(path_str)
             if not path.is_absolute():
                 abs_path = _my_path / path
@@ -44,7 +52,8 @@ def main():
 
         if args.meta:
             logger.info("Building metadata.")
-            df_metadata, df_ih = build_metadata(data=df_dataset, return_ih=True, verbose=args.verbose, **kwargs)
+            df_metadata, df_ih = integrator.build_metadata(data=df_dataset, return_ih=True,
+                                                           verbose=args.verbose, **kwargs)
 
         if args.matilda:
             if conf.get('feat_select'):
@@ -60,8 +69,17 @@ def main():
                 selected, df_metadata = featfilt(df_metadata, **param_dict)
                 logger.info("Selected features: {0}".format(selected))
 
-            logger.info("Running matilda.")
-            _ = run_matilda(metadata=df_metadata, rootdir=conf.get('rootdir'), matildadir=conf.get('matildadir'))
+            isa_engine = str.lower(conf.get('isa_engine'))
+            logger.info(f"Running Instance Space Analysis with {repr(isa_engine)} engine.")
+            if isa_engine == 'python':
+                integrator.run_isa(rootdir=rootdir_path)
+            elif isa_engine == 'matlab':
+                _ = integrator.run_matilda(metadata=df_metadata, rootdir=conf.get('rootdir'),
+                                           matildadir=conf.get('matildadir'))
+            elif isa_engine == 'matlab_compiled':
+                integrator.run_matilda_module(rootdir=rootdir_path)
+            else:
+                raise RuntimeError(f"Unknown ISA engine {repr(isa_engine)}.")
 
         if args.app:
             logging.getLogger().setLevel(logging.WARNING)
@@ -121,6 +139,8 @@ if __name__ == "__main__":
     args = parser.parse_args()
     print("run 'python3 -m pyhard -h' for help.")
 
+    # Temporary solution for known warnings
+    logging.getLogger("param").setLevel(logging.ERROR)
     if not args.graphene:
         sh = logging.StreamHandler()
         if args.verbose:
@@ -129,6 +149,13 @@ if __name__ == "__main__":
             sh.setLevel(logging.INFO)
         sh.setFormatter(formatter)
         logging.getLogger().addHandler(sh)
+    else:
+        with open(log_file, 'w'):
+            pass
+        fh = RotatingFileHandler(log_file, maxBytes=1e6, backupCount=5)
+        fh.setLevel(logging.INFO)
+        fh.setFormatter(formatter)
+        logging.getLogger().addHandler(fh)
 
     if args.demo:
         print("Press ^C to exit demo")
